@@ -111,8 +111,9 @@ bool CD::read_status( const bool force ) throw()
                               ch.cdsc_reladdr.msf.second,
                               ch.cdsc_reladdr.msf.frame );
         break;
-      case CDROM_AUDIO_PAUSED: status = paused; break;
-      case CDROM_AUDIO_INVALID: if( status != playing ) break;
+      case CDROM_AUDIO_PAUSED   : status = paused; break;
+      case CDROM_AUDIO_INVALID  :
+      case CDROM_AUDIO_NO_STATUS:
       case CDROM_AUDIO_COMPLETED:
         if( status == playing )
           {
@@ -121,7 +122,6 @@ bool CD::read_status( const bool force ) throw()
           }
         break;
       case CDROM_AUDIO_ERROR: status = stopped; break;
-      case CDROM_AUDIO_NO_STATUS: break;
       }
     }
   if( status == no_disc && old_status != no_disc )
